@@ -8,13 +8,13 @@ use crate::cmd::{
     fetchpost::fetchpost_cmd, fill::fill_cmd, fixlengths::fixlengths_cmd, flatten::flatten_cmd,
     fmt::fmt_cmd, foreach::foreach_cmd, frequency::frequency_cmd, geocode::geocode_cmd,
     headers::headers_cmd, index::index_cmd, input::input_cmd, join::join_cmd, joinp::joinp_cmd,
-    json::json_cmd, jsonl::jsonl_cmd, luau::luau_cmd, partition::partition_cmd, prompt::prompt_cmd,
-    pseudo::pseudo_cmd, python::py_cmd, rename::rename_cmd, replace::replace_cmd,
-    reverse::reverse_cmd, safenames::safenames_cmd, sample::sample_cmd, schema::schema_cmd,
-    search::search_cmd, searchset::searchset_cmd, select::select_cmd, slice::slice_cmd,
-    snappy::snappy_cmd, sniff::sniff_cmd, sort::sort_cmd, sortcheck::sortcheck_cmd,
-    split::split_cmd, sqlp::sqlp_cmd, stats::stats_cmd, table::table_cmd, to::to_cmd,
-    tojsonl::tojsonl_cmd, transpose::transpose_cmd, validate::validate_cmd,
+    json::json_cmd, jsonl::jsonl_cmd, lens::lens_cmd, luau::luau_cmd, partition::partition_cmd,
+    pro::pro_cmd, prompt::prompt_cmd, pseudo::pseudo_cmd, python::py_cmd, rename::rename_cmd,
+    replace::replace_cmd, reverse::reverse_cmd, safenames::safenames_cmd, sample::sample_cmd,
+    schema::schema_cmd, search::search_cmd, searchset::searchset_cmd, select::select_cmd,
+    slice::slice_cmd, snappy::snappy_cmd, sniff::sniff_cmd, sort::sort_cmd,
+    sortcheck::sortcheck_cmd, split::split_cmd, sqlp::sqlp_cmd, stats::stats_cmd, table::table_cmd,
+    to::to_cmd, tojsonl::tojsonl_cmd, transpose::transpose_cmd, validate::validate_cmd,
 };
 
 pub fn build_cli() -> Command {
@@ -59,8 +59,10 @@ pub fn build_cli() -> Command {
             joinp_cmd(),
             json_cmd(),
             jsonl_cmd(),
+            lens_cmd(),
             luau_cmd(),
             partition_cmd(),
+            pro_cmd(),
             prompt_cmd(),
             pseudo_cmd(),
             py_cmd(),
