@@ -171,6 +171,7 @@ applydp options:
     -j, --jobs <arg>            The number of jobs to run in parallel.
                                 When not set, the number of jobs is set to the number of CPUs detected.
     -b, --batch <size>          The number of rows per batch to load into memory, before running in parallel.
+                                Set to 0 to load all rows in one batch.
                                 [default: 50000]
 
 Common options:
@@ -241,7 +242,7 @@ struct Args {
     flag_comparand:   String,
     flag_replacement: String,
     flag_formatstr:   String,
-    flag_batch:       u32,
+    flag_batch:       usize,
     flag_jobs:        Option<usize>,
     flag_new_column:  Option<String>,
     flag_output:      Option<String>,
@@ -309,7 +310,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         dynfmt_fields.sort_unstable();
 
         // now, get the indices of the columns for the lookup vec
-        let (safe_headers, _) = util::safe_header_names(&headers, false, false, None, "", true);
+        let (safe_headers, _) = util::safe_header_names(&headers, false, false, &None, "", true);
         for (i, field) in safe_headers.iter().enumerate() {
             if dynfmt_fields.binary_search(&field.as_str()).is_ok() {
                 let field_with_curly = format!("{{{field}}}");
@@ -377,7 +378,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut batch_record = csv::StringRecord::new();
 
     // reuse batch buffers
-    let batchsize: usize = args.flag_batch as usize;
+    let batchsize: usize = if args.flag_batch == 0 {
+        util::count_rows(&rconfig)? as usize
+    } else {
+        args.flag_batch
+    };
     let mut batch = Vec::with_capacity(batchsize);
     let mut batch_results = Vec::with_capacity(batchsize);
 
