@@ -84,6 +84,7 @@ datefmt options:
     -j, --jobs <arg>            The number of jobs to run in parallel.
                                 When not set, the number of jobs is set to the number of CPUs detected.
     -b, --batch <size>          The number of rows per batch to load into memory, before running in parallel.
+                                Set to 0 to load all rows in one batch.
                                 [default: 50000]
 
 Common options:
@@ -132,7 +133,7 @@ struct Args {
     flag_default_tz:     Option<String>,
     flag_utc:            bool,
     flag_zulu:           bool,
-    flag_batch:          u32,
+    flag_batch:          usize,
     flag_jobs:           Option<usize>,
     flag_new_column:     Option<String>,
     flag_output:         Option<String>,
@@ -252,7 +253,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut batch_record = csv::StringRecord::new();
 
     // reuse batch buffers
-    let batchsize: usize = args.flag_batch as usize;
+    let batchsize: usize = if args.flag_batch == 0 {
+        util::count_rows(&rconfig)? as usize
+    } else {
+        args.flag_batch
+    };
     let mut batch = Vec::with_capacity(batchsize);
     let mut batch_results = Vec::with_capacity(batchsize);
 
