@@ -15,33 +15,26 @@ as the command will need to load all the column's values into memory, potentiall
 causing Out-of-Memory (OOM) errors for larger-than-memory datasets.
 
 To overcome this, the frequency command can use the stats cache if it exists to get
-column cardinalities. This short-circuits frequency compilation for columns
-with all unique values (i.e. where rowcount == cardinality), eliminating the need to
-maintain a in-memory hashmap for ID columns. This allows the command to compute frequencies
-for larger-than-memory datasets.
-
-However, in the current implementation, the stats cache takes a while to load, eliminating
-the performance benefits of cardinality-based frequency tables.
-See https://github.com/jqnatividad/qsv/issues/2040
-
-Therefore, only use the `--stats-mode` option if you have a large dataset with columns
-that have all unique values and you want to avoid OOM errors.
+column cardinalities. This short-circuits frequency compilation for columns with
+all unique values (i.e. where rowcount == cardinality), eliminating the need to
+maintain an in-memory hashmap for ID columns. This allows `frequency` to handle
+larger-than-memory datasets with the added benefit of also making it faster when
+working with datasets with ID columns.
 
 STATS_MODE "none" NOTES:
 
-    If --stats mode is set to "none", the frequency command will compute frequencies for
-    all columns regardless of cardinality, even for columns with all unique values.
+    If --stats mode is set to "none", the frequency command will compute frequencies
+    for all columns regardless of cardinality, even for columns with all unique values.
+    In this case, the unique limit (--unq-limit) is particularly useful when a column
+    has all unique values  and --limit is set to 0.
+    Without a unique limit, the frequency table for that column will be the same as
+    the number of rows in the data.
+    With a unique limit, the frequency table will be a sample of N unique values,
+    all with a count of 1.
 
-    In this case, the unique limit (--unq-limit) is particularly useful when a column has
-    all unique values  and --limit is set to 0.
-    Without a unique limit, the frequency table for that column will be the same as the
-    number of rows in the data.
-    With a unique limit, the frequency table will be a sample of N unique values, all with
-    a count of 1.
-
-    Further, the --lmt-threshold option also allows you to apply the --limit & --unq-limit
-    options only when the number of unique items in a column is greater than or equal to the
-    threshold. This is useful when you want to apply limits only to columns with a large number
+    The --lmt-threshold option also allows you to apply the --limit and --unq-limit
+    options only when the number of unique items in a column >= threshold.
+    This is useful when you want to apply limits only to columns with a large number
     of unique items and not to columns with a small number of unique items.
 
 For examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_frequency.rs.
@@ -98,11 +91,12 @@ frequency options:
                             There are three modes:
                               auto: use stats cache if it already exists to get column cardinalities.
                                     For columns with all unique values, "<ALL_UNIQUE>" will be used.
-                              force: force stats calculation to get cardinalities.
+                              force: force stats calculation to get cardinalities. If the stats cache
+                                    does not exist, it will be created.
                               none: don't use cardinality information.
                                     For columns with all unique values, the first N sorted unique
                                     values (based on the --limit and --unq-limit options) will be used.
-                            [default: none]
+                            [default: auto]
    --all-unique-text <arg>  The text to use for the "<ALL_UNIQUE>" category.
                             [default: <ALL_UNIQUE>]
     -j, --jobs <arg>        The number of jobs to run in parallel.
@@ -596,8 +590,7 @@ impl Args {
             "_schema" => StatsMode::Schema, // only meant for internal use by schema command
             _ => return fail_incorrectusage_clierror!("Invalid stats mode"),
         };
-        let (csv_fields, csv_stats, stats_col_index_map) =
-            get_stats_records(&schema_args, stats_mode)?;
+        let (csv_fields, csv_stats) = get_stats_records(&schema_args, stats_mode)?;
 
         if stats_mode == StatsMode::None || stats_mode == StatsMode::Schema || csv_fields.is_empty()
         {
@@ -614,30 +607,24 @@ impl Args {
             csv_fields.len() == csv_stats.len(),
             "Mismatch between the number of fields and stats records"
         );
-        let col_cardinality_vec: Vec<(String, usize)> = csv_stats
+        let col_cardinality_vec: Vec<(String, u64)> = csv_stats
             .iter()
             .enumerate()
-            .map(|(i, _record)| {
+            .map(|(i, stats_record)| {
                 // get the column name and stats record
                 // safety: we know that csv_fields and csv_stats have the same length
                 let col_name = csv_fields.get(i).unwrap();
-                let stats_record = csv_stats.get(i).unwrap().clone().to_record(4, false);
-
-                let col_cardinality = match stats_record.get(stats_col_index_map["cardinality"]) {
-                    Some(s) => s.parse::<usize>().unwrap_or(0_usize),
-                    None => 0_usize,
-                };
                 (
                     simdutf8::basic::from_utf8(col_name)
                         .unwrap_or(NON_UTF8_ERR)
                         .to_string(),
-                    col_cardinality,
+                    stats_record.cardinality,
                 )
             })
             .collect();
 
         // now, get the unique headers, where cardinality == rowcount
-        let row_count = util::count_rows(&self.rconfig())? as usize;
+        let row_count = util::count_rows(&self.rconfig())?;
         FREQ_ROW_COUNT.set(row_count as u64).unwrap();
 
         let mut all_unique_headers_vec: Vec<usize> = Vec::with_capacity(5);
@@ -659,7 +646,9 @@ impl Args {
         let headers = rdr.byte_headers()?;
         let all_unique_headers_vec = self.get_unique_headers(headers)?;
 
-        UNIQUE_COLUMNS.set(all_unique_headers_vec).unwrap();
+        UNIQUE_COLUMNS
+            .set(all_unique_headers_vec)
+            .map_err(|_| "Cannot set UNIQUE_COLUMNS")?;
 
         let sel = self.rconfig().selection(headers)?;
         Ok((sel.select(headers).map(<[u8]>::to_vec).collect(), sel))
