@@ -21,8 +21,9 @@ Common options:
     -o, --output <file>    Write output to <file> instead of stdout.
     -d, --delimiter <arg>  The field delimiter for reading CSV data.
                            Must be a single character. (default: ,)
-    --no-memcheck          Do not check if there is enough memory to load the
-                           entire CSV into memory. Ignored with --multipass.
+    --memcheck             Check if there is enough memory to load the entire
+                           CSV into memory using CONSERVATIVE heuristics.
+                           Ignored when --multipass option is enabled.
 "#;
 
 use std::str;
@@ -37,11 +38,11 @@ use crate::{
 
 #[derive(Deserialize)]
 struct Args {
-    arg_input:        Option<String>,
-    flag_output:      Option<String>,
-    flag_delimiter:   Option<Delimiter>,
-    flag_multipass:   bool,
-    flag_no_memcheck: bool,
+    arg_input:      Option<String>,
+    flag_output:    Option<String>,
+    flag_delimiter: Option<Delimiter>,
+    flag_multipass: bool,
+    flag_memcheck:  bool,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
@@ -64,7 +65,7 @@ impl Args {
     fn in_memory_transpose(&self) -> CliResult<()> {
         // we're loading the entire file into memory, we need to check avail mem
         if let Some(path) = self.rconfig().path {
-            util::mem_file_check(&path, false, self.flag_no_memcheck)?;
+            util::mem_file_check(&path, false, self.flag_memcheck)?;
         }
 
         let mut rdr = self.rconfig().reader()?;
