@@ -127,34 +127,7 @@ impl Config {
             Some(ref s) if &**s == "-" => (None, default_delim, false),
             Some(ref s) => {
                 let path = PathBuf::from(s);
-                let file_extension = path
-                    .extension()
-                    .unwrap_or_default()
-                    .to_str()
-                    .unwrap()
-                    .to_ascii_lowercase();
-                let mut snappy = false;
-                let delim = if file_extension == "tsv" || file_extension == "tab" {
-                    b'\t'
-                } else if file_extension == "ssv" {
-                    b';'
-                } else if file_extension == "csv" {
-                    b','
-                } else {
-                    let filename = path.file_name().unwrap().to_str().unwrap();
-                    if filename.ends_with(".csv.sz") {
-                        snappy = true;
-                        b','
-                    } else if filename.ends_with(".tsv.sz") || filename.ends_with(".tab.sz") {
-                        snappy = true;
-                        b'\t'
-                    } else if filename.ends_with(".ssv.sz") {
-                        snappy = true;
-                        b';'
-                    } else {
-                        default_delim
-                    }
-                };
+                let (file_extension, delim, snappy) = get_delim_by_extension(&path, default_delim);
                 (Some(path), delim, snappy || file_extension.ends_with("sz"))
             },
         };
@@ -579,3 +552,30 @@ impl Config {
             .from_writer(wtr)
     }
 }
+
+pub fn get_delim_by_extension(path: &Path, default_delim: u8) -> (String, u8, bool) {
+    let mut snappy = false;
+    let file_extension = path
+        .extension()
+        .unwrap_or_default()
+        .to_str()
+        .unwrap()
+        .to_ascii_lowercase();
+    #[allow(clippy::case_sensitive_file_extension_comparisons)]
+    let delim = match file_extension.as_str() {
+        "tsv" | "tab" => b'\t',
+        "ssv" => b';',
+        "csv" => b',',
+        _ => {
+            let snappied_ext = path.extension().and_then(|ext| ext.to_str()).unwrap_or("_");
+            snappy = snappied_ext.ends_with(".sz");
+            match snappied_ext {
+                "csv.sz" => b',',
+                "tsv.sz" | "tab.sz" => b'\t',
+                "ssv.sz" => b';',
+                _ => default_delim,
+            }
+        },
+    };
+    (file_extension, delim, snappy)
+}
