@@ -182,6 +182,11 @@ Please choose one of the following commands:",
                 util::log_end(qsv_args, now);
                 QsvExitCode::Good
             },
+            Err(CliError::Help(usage_text)) => {
+                wout!("{usage_text}");
+                util::log_end(qsv_args, now);
+                QsvExitCode::Good
+            },
             Err(CliError::Flag(err)) => {
                 werr!("{err}");
                 util::log_end(qsv_args, now);
