@@ -482,14 +482,12 @@ fn frequency_all_unique_with_stats_cache() {
     stats_cmd
         .arg(testdata.clone())
         .arg("--cardinality")
-        .arg("--stats-binout");
+        .arg("--stats-jsonl");
 
     wrk.assert_success(&mut stats_cmd);
 
     let mut cmd = wrk.command("frequency");
-    cmd.args(["--select", "1"])
-        .args(["--stats-mode", "auto"])
-        .arg(testdata);
+    cmd.args(["--select", "1"]).arg(testdata);
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![
@@ -508,7 +506,7 @@ fn frequency_all_unique_with_stats_cache_alt_all_unique_text() {
     stats_cmd
         .arg(testdata.clone())
         .arg("--cardinality")
-        .arg("--stats-binout");
+        .arg("--stats-jsonl");
 
     wrk.assert_success(&mut stats_cmd);
 
@@ -555,7 +553,7 @@ fn frequency_all_unique_stats_mode_none() {
     stats_cmd
         .arg(testdata.clone())
         .arg("--cardinality")
-        .arg("--stats-binout");
+        .arg("--stats-jsonl");
 
     wrk.assert_success(&mut stats_cmd);
 
@@ -673,9 +671,19 @@ fn prop_frequency_indexed() {
 }
 
 fn param_prop_frequency(name: &str, rows: CsvData, idx: bool) -> bool {
-    if !rows.is_empty() && rows[0][0].len() == 3 && rows[0][0] == "\u{FEFF}" {
+    if !rows.is_empty() {
         return true;
     }
+
+    let rows_check = rows.clone();
+
+    for row in rows_check.into_iter() {
+        for field in row.into_iter() {
+            if field.contains("\u{FEFF}") {
+                return true;
+            }
+        }
+    }
     let wrk = Workdir::new(name);
     if idx {
         wrk.create_indexed("in.csv", rows.clone());
