@@ -15,7 +15,31 @@ fn validate_good_csv() {
     let mut cmd = wrk.command("validate");
     cmd.arg("data.csv");
 
-    wrk.output(&mut cmd);
+    wrk.assert_success(&mut cmd);
+}
+
+#[test]
+fn validate_good_tab() {
+    let wrk = Workdir::new("validate_good_tab").flexible(true);
+    let tabfile = wrk.load_test_file("boston311-100.tab");
+    let mut cmd = wrk.command("validate");
+    cmd.arg(tabfile);
+
+    wrk.assert_success(&mut cmd);
+
+    let got: String = wrk.stdout(&mut cmd);
+    let expected = r#"Valid: 29 Columns: ("case_enquiry_id", "open_dt", "target_dt", "closed_dt", "ontime", "case_status", "closure_reason", "case_title", "subject", "reason", "type", "queue", "department", "submittedphoto", "closedphoto", "location", "fire_district", "pwd_district", "city_council_district", "police_district", "neighborhood", "neighborhood_services_district", "ward", "precinct", "location_street_name", "location_zipcode", "latitude", "longitude", "source"); Records: 100; Delimiter: TAB"#;
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn validate_bad_tsv() {
+    let wrk = Workdir::new("validate_bad_tsv").flexible(true);
+    let tabfile = wrk.load_test_file("boston311-100-bad.tsv");
+    let mut cmd = wrk.command("validate");
+    cmd.arg(tabfile);
+
+    wrk.assert_err(&mut cmd);
 }
 
 #[test]
@@ -34,8 +58,7 @@ fn validate_good_csv_msg() {
     cmd.arg("data.csv");
 
     let got: String = wrk.stdout(&mut cmd);
-    let expected =
-        r#"Valid: 3 columns ("title", "name", "real age (earth years)") and 3 records detected."#;
+    let expected = r#"Valid: 3 Columns: ("title", "name", "real age (earth years)"); Records: 3; Delimiter: ,"#;
     assert_eq!(got, expected);
 }
 
@@ -50,8 +73,7 @@ fn validate_empty_csv_msg() {
     cmd.arg("data.csv");
 
     let got: String = wrk.stdout(&mut cmd);
-    let expected =
-        r#"Valid: 3 columns ("title", "name", "real age (earth years)") and 0 records detected."#;
+    let expected = r#"Valid: 3 Columns: ("title", "name", "real age (earth years)"); Records: 0; Delimiter: ,"#;
     assert_eq!(got, expected);
 }
 
@@ -304,6 +326,32 @@ fn validate_adur_public_toilets_dataset_with_json_schema_valid_output() {
     wrk.assert_err(&mut cmd);
 }
 
+#[test]
+fn validate_with_schema_noheader() {
+    let wrk = Workdir::new("validate_with_schema_noheader").flexible(true);
+
+    // copy schema file to workdir
+    let schema: String = wrk.load_test_resource("public-toilets-schema.json");
+    wrk.create_from_string("schema.json", &schema);
+
+    // copy csv file to workdir
+    let csv: String = wrk.load_test_resource("adur-public-toilets-valid.csv");
+    wrk.create_from_string("data.csv", &csv);
+
+    // run validate command
+    let mut cmd = wrk.command("validate");
+    cmd.arg("data.csv")
+        .arg("schema.json")
+        .arg("--no-headers")
+        .args(["--valid-output", "-"]);
+
+    let got = wrk.output_stderr(&mut cmd);
+    let expected = "Cannot validate CSV without headers against a JSON Schema.\n".to_string();
+    assert_eq!(got, expected);
+
+    wrk.assert_err(&mut cmd);
+}
+
 #[test]
 fn validate_adur_public_toilets_dataset_with_json_schema_url() {
     let wrk = Workdir::new("validate").flexible(true);
